Quickstart
==========


Assuming you already have an Open Data Cube instance, Explorer will use
its existing settings.

Install Explorer:

.. code-block:: text

    pip install datacube-explorer

Generate summaries for all of your products:

.. code-block:: text

    cubedash-gen --init --all

Run Explorer locally:

.. code-block:: text

    cubedash-run

It will now be viewable on [http://localhost:8090](https://localhost:8090)
